@@ -17,7 +17,7 @@ from ae.base import UNSET
 from ae.deep import deep_object, deep_replace                                               # type: ignore
 
 
-__version__ = '0.2.7'
+__version__ = '0.3.7'
 
 
 class DynamicChildrenBehavior:
@@ -57,7 +57,7 @@ class DynamicChildrenBehavior:
         """ add dynamic creation and refresh of children to this layout (Popup/Dropdown/...) widget. """
         super().__init__(**kwargs)
         self._is_popup = isinstance(self, Popup)    # True if inherits from :class:`~kivy.uix.popup.Popup`
-        self._map_children = list()
+        self._map_children = []
         self.bind(child_data_maps=self.refresh_child_data_widgets)
         self.refresh_child_data_widgets(self, **kwargs)
 
@@ -83,13 +83,13 @@ class DynamicChildrenBehavior:
             if isinstance(cls, str):
                 cls = Factory.get(cls)
 
-            init_child_kwargs = child_data.get('kwargs', dict())
+            init_child_kwargs = child_data.get('kwargs', {})
             deep_replace(init_child_kwargs, lambda p, k, v: self if v == 'replace_with_data_map_container' else UNSET)
             child = cls(**init_child_kwargs)
 
             child.child_index = child_index
 
-            attributes = child_data.get('attributes', dict())
+            attributes = child_data.get('attributes', {})
             deep_replace(attributes, lambda p, k, v: self if v == 'replace_with_data_map_container' else UNSET)
             deep_replace(attributes, lambda p, k, v: child if v == 'replace_with_data_map_child' else UNSET)
             for attr_name, attr_value in attributes.items():
